@@ -3,7 +3,7 @@ package Acme::CPANModules::GrepVariants;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-07-02'; # DATE
 our $DIST = 'Acme-CPANModules-GrepVariants'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use strict;
 use Acme::CPANModulesUtil::Misc;
@@ -18,14 +18,16 @@ uses.
 
 **2a. Improvements in recursive searching against files**
 
-**ack**. Created in 2005 by Andy Lester, <pm:ack> is the granddaddy of grep-like
-programs that try to improve the experience of using grep to search for text in
-source code. ack skips VCS directories like `.git` or `.svn`, and understands
-file types so it doesn't look into giant `.mp4`s and other binaries by default.
-ack has spurred the development of other ack improvements (mostly in speed
-aspect) like The Silver Searcher (`ag`) or `ripgrep`. `git` also now includes a
-`git-grep` utility. ack has a website: <https://beyondgrep.com>. See also
-<https://betterthanack.com>.
+<prog:ack>. Created in 2005 by Andy Lester, <pm:ack> is the granddaddy of
+grep-like programs that try to improve the experience of using grep to search
+for text in source code. ack skips VCS directories like `.git` or `.svn`, and
+understands file types so it doesn't look into giant `.mp4`s and other binaries
+by default. ack has spurred the development of other ack improvements (mostly in
+speed aspect) like The Silver Searcher (`ag`) or `ripgrep`. `git` also now
+includes a `git-grep` utility. ack has a website: <https://beyondgrep.com>. See
+also <https://betterthanack.com>.
+
+<prog:gre> from <pm:App::Gre>
 
 
 **2b. Improvements in specifying multiple patterns**
@@ -76,12 +78,34 @@ modules. It's basically a shortcut for something like this:
     % pmlist -Rx | xargs grep PAT
     % grep PAT `pmlist -Rx`
 
+<prog:cpangrep> from <pm:App::cpangrep> is a CLI for web service
+<https://cpan.grep.me>, which is no longer operating. To grep from files on
+CPAN, use <https://metacpan.org>.
+
 <prog:grepl> from <pm:App::Grepl> uses <pm:PPI> to let you grep over Perl
 *documents*; it allows you to do things like: search only in Perl code comments
 or inside string literals.
 
+<prog:podgrep> from <pm:pmtools> greps from POD sections of Perl source.
 
-**4b. Variants: other alternate sources**
+
+**4b. Variants: alternate source: CSV**
+
+<prog:csvgrep> from <pm:csvgrep>
+
+<prog:csv-grep> from <pm:App::CSVUtils> allows you to apply Perl code against
+rows of CSV.
+
+
+**4c. Variants: alternate source: word lists**
+
+<prog:wordlist> from <pm:App::wordlist> greps words from wordlist modules
+(modules that contains word lists, see WordList).
+
+
+**4d. Variants: other alternate sources**
+
+<prog:grep-from-bash-history> from <pm:App::BashHistoryUtils>.
 
 <prog:grep-from-iod> from <pm:App::IODUtils>.
 
@@ -91,6 +115,11 @@ or inside string literals.
 
 <prog:grep-from-exchange> from <pm:App::CryptoCurrencyUtils>.
 
+<prog:jgrep> from <pm:App::JsonLogUtils>
+
+<prog:ptargrep> from <pm:Archive::Tar> searches against table of contents of tar
+files.
+
 
 **5a. Variants: searching URLs**
 
@@ -99,6 +128,13 @@ specify regex that matches URLs yourself; you can just add additional criteria
 for the URLs, e.g. whether the host part must contain some text, or whether a
 certain query parameter must match some pattern.
 
+
+**5b. Variants: searching dates**
+
+<prog:grep-date> from L<App::grep::date> greps for dates in lines of text.
+
+<prog:dategrep> from L<App::dategrep> prints lines matching a date range.
+
 _
 
 our $LIST = {
@@ -125,7 +161,7 @@ Acme::CPANModules::GrepVariants - Grep-like CLI utilities available on CPAN
 
 =head1 VERSION
 
-This document describes version 0.003 of Acme::CPANModules::GrepVariants (from Perl distribution Acme-CPANModules-GrepVariants), released on 2021-07-02.
+This document describes version 0.005 of Acme::CPANModules::GrepVariants (from Perl distribution Acme-CPANModules-GrepVariants), released on 2021-07-02.
 
 =head1 DESCRIPTION
 
@@ -137,14 +173,16 @@ uses.
 
 B<2a. Improvements in recursive searching against files>
 
-B<ack>. Created in 2005 by Andy Lester, L<ack> is the granddaddy of grep-like
-programs that try to improve the experience of using grep to search for text in
-source code. ack skips VCS directories like C<.git> or C<.svn>, and understands
-file types so it doesn't look into giant C<.mp4>s and other binaries by default.
-ack has spurred the development of other ack improvements (mostly in speed
-aspect) like The Silver Searcher (C<ag>) or C<ripgrep>. C<git> also now includes a
-C<git-grep> utility. ack has a website: L<https://beyondgrep.com>. See also
-L<https://betterthanack.com>.
+L<ack>. Created in 2005 by Andy Lester, L<ack> is the granddaddy of
+grep-like programs that try to improve the experience of using grep to search
+for text in source code. ack skips VCS directories like C<.git> or C<.svn>, and
+understands file types so it doesn't look into giant C<.mp4>s and other binaries
+by default. ack has spurred the development of other ack improvements (mostly in
+speed aspect) like The Silver Searcher (C<ag>) or C<ripgrep>. C<git> also now
+includes a C<git-grep> utility. ack has a website: L<https://beyondgrep.com>. See
+also L<https://betterthanack.com>.
+
+L<gre> from L<App::Gre>
 
 B<2b. Improvements in specifying multiple patterns>
 
@@ -192,11 +230,31 @@ modules. It's basically a shortcut for something like this:
  % pmlist -Rx | xargs grep PAT
  % grep PAT C<pmlist -Rx>
 
+L<cpangrep> from L<App::cpangrep> is a CLI for web service
+L<https://cpan.grep.me>, which is no longer operating. To grep from files on
+CPAN, use L<https://metacpan.org>.
+
 L<grepl> from L<App::Grepl> uses L<PPI> to let you grep over Perl
 I<documents>; it allows you to do things like: search only in Perl code comments
 or inside string literals.
 
-B<4b. Variants: other alternate sources>
+L<podgrep> from L<pmtools> greps from POD sections of Perl source.
+
+B<4b. Variants: alternate source: CSV>
+
+L<csvgrep> from L<csvgrep>
+
+L<csv-grep> from L<App::CSVUtils> allows you to apply Perl code against
+rows of CSV.
+
+B<4c. Variants: alternate source: word lists>
+
+L<wordlist> from L<App::wordlist> greps words from wordlist modules
+(modules that contains word lists, see WordList).
+
+B<4d. Variants: other alternate sources>
+
+L<grep-from-bash-history> from L<App::BashHistoryUtils>.
 
 L<grep-from-iod> from L<App::IODUtils>.
 
@@ -206,6 +264,11 @@ L<grep-from-coin> from L<App::CryptoCurrencyUtils>.
 
 L<grep-from-exchange> from L<App::CryptoCurrencyUtils>.
 
+L<jgrep> from L<App::JsonLogUtils>
+
+L<ptargrep> from L<Archive::Tar> searches against table of contents of tar
+files.
+
 B<5a. Variants: searching URLs>
 
 L<App::grep::url> greps URLs from lines of input. You don't have to manually
@@ -213,6 +276,12 @@ specify regex that matches URLs yourself; you can just add additional criteria
 for the URLs, e.g. whether the host part must contain some text, or whether a
 certain query parameter must match some pattern.
 
+B<5b. Variants: searching dates>
+
+L<grep-date> from L<App::grep::date> greps for dates in lines of text.
+
+L<dategrep> from L<App::dategrep> prints lines matching a date range.
+
 =head1 ACME::MODULES ENTRIES
 
 =over
@@ -221,6 +290,8 @@ certain query parameter must match some pattern.
 
 =item * L<ack>
 
+=item * L<App::Gre>
+
 =item * L<App::abgrep>
 
 =item * L<App::Greple>
@@ -233,16 +304,32 @@ certain query parameter must match some pattern.
 
 =item * L<App::pmgrep>
 
+=item * L<App::cpangrep>
+
 =item * L<App::Grepl>
 
 =item * L<PPI>
 
+=item * L<pmtools>
+
+=item * L<csvgrep>
+
+=item * L<App::CSVUtils>
+
+=item * L<App::wordlist>
+
+=item * L<App::BashHistoryUtils>
+
 =item * L<App::IODUtils>
 
 =item * L<App::INIUtils>
 
 =item * L<App::CryptoCurrencyUtils>
 
+=item * L<App::JsonLogUtils>
+
+=item * L<Archive::Tar>
+
 =item * L<App::grep::url>
 
 =back
